@@ -9,6 +9,8 @@ from pathlib import Path
 from typing import Optional, Dict, Any
 from rich.console import Console
 from rich.prompt import Prompt, Confirm
+from rich.syntax import Syntax
+from rich.text import Text
 
 from ... import __version__
 from ... import address
@@ -106,12 +108,7 @@ def handle_init(ai: Optional[bool], key: Optional[str], template: Optional[str],
     # Track temp directory for cleanup
     temp_project_dir = None
 
-    # Header with color
-    if not yes:
-        console.print("\n[bold cyan]🧅 ConnectOnion Project Initializer[/bold cyan]")
-        console.print("[cyan]" + "=" * 40 + "[/cyan]")
-        console.print(f"\n📁 Initializing: [bold]{project_name}[/bold]")
-        console.print(f"📍 Location: [bold]{current_dir}[/bold]\n")
+    # Header removed for cleaner output
 
     # Check for special directories
     warning = get_special_directory_warning(current_dir)
@@ -164,31 +161,13 @@ def handle_init(ai: Optional[bool], key: Optional[str], template: Optional[str],
         # Detect provider from the provided key
         provider, key_type = detect_api_provider(api_key)
 
-    # Template selection
-    if not template and not yes:
-        # Check if directory has existing files
-        has_existing_files = not is_directory_empty(current_dir)
-
-        if has_existing_files:
-            # For existing projects, offer option to just add ConnectOnion config
-            template_info = [
-                ('none', '⚙️  Just add ConnectOnion config', 'Add .co folder and .env without any template files'),
-                ('minimal', '📦 Minimal', 'Basic agent structure'),
-                ('playwright', '🎭 Playwright', 'Browser automation agent'),
-            ]
-            if ai:
-                template_info.append(('custom', '✨ Custom', 'AI-generated agent'))
-        else:
-            # For empty directories, use normal template options
-            template_info = get_template_info()
-            # Filter out custom if AI is disabled
-            if not ai:
-                template_info = [t for t in template_info if t[0] != 'custom']
-
-        template = interactive_menu(template_info, "Choose a template:")
-    elif not template:
-        # Default to 'none' for existing projects, 'minimal' for new
-        template = 'none' if not is_directory_empty(current_dir) else 'minimal'
+    # Template selection - default to 'none' (just add .co folder) unless --template provided
+    if not template:
+        # No --template flag provided, just add ConnectOnion config
+        template = 'none'
+        if not yes:
+            console.print(f"\n{Colors.GREEN}✓ Adding ConnectOnion config (.co folder){Colors.END} (use --template <name> for full templates)")
+    # else: template has a specific value from --template <name>
 
     # Handle custom template
     custom_code = None
@@ -255,6 +234,14 @@ def handle_init(ai: Optional[bool], key: Optional[str], template: Optional[str],
         agent_file.write_text(custom_code)
         files_created.append("agent.py")
 
+    # AUTHENTICATE FIRST - so we have OPENONION_API_KEY to add to .env
+    global_co_dir = Path.home() / ".co"
+    if not global_co_dir.exists():
+        ensure_global_config()
+
+    # Authenticate to get OPENONION_API_KEY (always, for everyone)
+    auth_success = authenticate(global_co_dir, save_to_project=False)
+
     # Handle .env file - append API keys from global config
     env_path = Path(current_dir) / ".env"
     global_dir = Path.home() / ".co"
@@ -272,7 +259,7 @@ def handle_init(ai: Optional[bool], key: Optional[str], template: Optional[str],
                     key = line.split('=')[0].strip()
                     existing_keys.add(key)
 
-    # Read global keys
+    # Read global keys (now includes OPENONION_API_KEY from auth)
     keys_to_add = []
     if global_keys_env.exists():
         with open(global_keys_env, 'r') as f:
@@ -288,7 +275,7 @@ def handle_init(ai: Optional[bool], key: Optional[str], template: Optional[str],
         provider_to_env = {
             "openai": "OPENAI_API_KEY",
             "anthropic": "ANTHROPIC_API_KEY",
-            "google": "GOOGLE_API_KEY",
+            "google": "GEMINI_API_KEY",
             "groq": "GROQ_API_KEY",
         }
         env_var = provider_to_env.get(provider, f"{provider.upper()}_API_KEY")
@@ -300,13 +287,13 @@ def handle_init(ai: Optional[bool], key: Optional[str], template: Optional[str],
         # Create new .env
         if keys_to_add:
             env_path.write_text('\n'.join(keys_to_add) + '\n')
-            console.print(f"{Colors.GREEN}✓ Created .env with API keys from ~/.co/keys.env{Colors.END}")
+            console.print(f"{Colors.GREEN}✓ Created .env with API keys{Colors.END}")
         else:
-            # Create with comments-only template (no fake keys)
+            # Fallback - should not happen now that we always auth
             env_content = """# Add your LLM API key(s) below (uncomment one and set value)
 # OPENAI_API_KEY=
 # ANTHROPIC_API_KEY=
-# GOOGLE_API_KEY=
+# GEMINI_API_KEY=
 # GROQ_API_KEY=
 
 # Optional: Override default model
@@ -319,9 +306,9 @@ def handle_init(ai: Optional[bool], key: Optional[str], template: Optional[str],
         with open(env_path, 'a') as f:
             if not existing_env_content.endswith('\n'):
                 f.write('\n')
-            f.write('\n# ConnectOnion API Keys\n')
+            f.write('\n# API Keys\n')
             f.write('\n'.join(keys_to_add) + '\n')
-        console.print(f"{Colors.GREEN}✓ Appended missing API keys to .env{Colors.END}")
+        console.print(f"{Colors.GREEN}✓ Updated .env with API keys{Colors.END}")
         files_created.append(".env (updated)")
     else:
         console.print(f"{Colors.GREEN}✓ .env already contains all necessary keys{Colors.END}")
@@ -330,56 +317,36 @@ def handle_init(ai: Optional[bool], key: Optional[str], template: Optional[str],
     co_dir = Path(current_dir) / ".co"
     co_dir.mkdir(exist_ok=True)
 
-    # Decide documentation placement
-    # For 'playwright' (browser-agent) template, we place a single doc at project root
-    # For others, we keep docs under .co/docs
+    # Create docs directory and copy documentation (always overwrite for latest version)
     docs_dir = co_dir / "docs"
-    place_single_root_doc = (template == 'playwright')
-    if not place_single_root_doc:
-        # Create docs directory and copy documentation (always overwrite for latest version)
-        if docs_dir.exists():
-            shutil.rmtree(docs_dir)
-        docs_dir.mkdir(exist_ok=True)
+    if docs_dir.exists():
+        shutil.rmtree(docs_dir)
+    docs_dir.mkdir(exist_ok=True)
 
     # Copy ConnectOnion documentation
     cli_dir = Path(__file__).parent.parent
 
-    # Always copy the vibe coding doc for all templates - it's the only doc we need
-    vibe_doc_copied = False
+    # Always copy the vibe coding doc for all templates - it's the master reference doc
+    master_doc = cli_dir / "docs" / "co-vibecoding-principles-docs-contexts-all-in-one.md"
 
-    # First try to find the vibe doc from template directory
-    if template != 'none' and template != 'custom':
-        template_doc = cli_dir / "templates" / template / "co-vibecoding-principles-docs-contexts-all-in-one.md"
-        if template_doc.exists():
-            if place_single_root_doc:
-                target_path = Path(current_dir) / "co-vibecoding-principles-docs-contexts-all-in-one.md"
-                shutil.copy2(template_doc, target_path)
-                files_created.append("co-vibecoding-principles-docs-contexts-all-in-one.md")
-            else:
-                shutil.copy2(template_doc, docs_dir / "co-vibe-coding-all-in-one.md")
-                files_created.append(".co/docs/co-vibe-coding-all-in-one.md")
-            vibe_doc_copied = True
+    if master_doc.exists():
+        # Copy to .co/docs/ (project metadata)
+        target_doc = docs_dir / "co-vibecoding-principles-docs-contexts-all-in-one.md"
+        shutil.copy2(master_doc, target_doc)
+        files_created.append(".co/docs/co-vibecoding-principles-docs-contexts-all-in-one.md")
 
-    # If not found in template, copy from master docs
-    if not vibe_doc_copied:
-        master_doc = cli_dir / "docs" / "co-vibecoding-principles-docs-contexts-all-in-one.md"
-        if master_doc.exists():
-            if place_single_root_doc:
-                target_path = Path(current_dir) / "co-vibecoding-principles-docs-contexts-all-in-one.md"
-                shutil.copy2(master_doc, target_path)
-                files_created.append("co-vibecoding-principles-docs-contexts-all-in-one.md")
-            else:
-                shutil.copy2(master_doc, docs_dir / "co-vibe-coding-all-in-one.md")
-                files_created.append(".co/docs/co-vibe-coding-all-in-one.md")
-            vibe_doc_copied = True
-
-    # Final check - vibe doc should be present
-    if not vibe_doc_copied:
-        print(f"Warning: Vibe coding documentation not found to copy to .co/docs/")
+        # ALSO copy to project root (always visible, easier to find)
+        root_doc = Path(current_dir) / "co-vibecoding-principles-docs-contexts-all-in-one.md"
+        shutil.copy2(master_doc, root_doc)
+        files_created.append("co-vibecoding-principles-docs-contexts-all-in-one.md")
+    else:
+        console.print(f"[yellow]⚠️  Warning: Vibe coding documentation not found at {master_doc}[/yellow]")
 
     # Use global identity instead of generating project keys
     # NO PROJECT KEYS - we use global address/email
-    addr_data = global_identity  # Use the global identity we loaded earlier
+    # Reload global config to get updated email_active after authentication
+    global_config = toml.load(global_co_dir / "config.toml") if (global_co_dir / "config.toml").exists() else global_config
+    addr_data = global_config.get("agent", global_identity)  # Use updated global identity
 
     # Note: We're NOT creating project-specific keys anymore
     # If user wants project-specific keys, they'll use 'co address' command
@@ -423,6 +390,7 @@ def handle_init(ai: Optional[bool], key: Optional[str], template: Optional[str],
 .co/cache/
 .co/logs/
 .co/history/
+co-vibecoding-principles-docs-contexts-all-in-one.md
 *.py[cod]
 __pycache__/
 todo.md
@@ -436,143 +404,40 @@ todo.md
             gitignore_path.write_text(gitignore_content.lstrip())
             files_created.append(".gitignore")
 
-    # Success message
-    console.print(f"\n{Colors.GREEN}✅ ConnectOnion project initialized!{Colors.END}")
+    # Success message with Rich formatting
+    console.print()
+    console.print(f"[bold green]✅ Initialized ConnectOnion in {project_name}[/bold green]")
+    console.print()
 
-    console.print(f"\n📁 Project: {Colors.BOLD}{project_name}{Colors.END}")
-    if template == 'none':
-        console.print(f"⚙️  Configuration: {Colors.BOLD}ConnectOnion config added{Colors.END}")
+    # Show different message based on whether agent.py exists
+    if template != 'none' and (Path(current_dir) / "agent.py").exists():
+        # Command with syntax highlighting - compact design
+        command = "python agent.py"
+        syntax = Syntax(
+            command,
+            "bash",
+            theme="monokai",
+            background_color="#272822",  # Monokai background color
+            padding=(0, 1)  # Minimal padding for tight fit
+        )
+        console.print(syntax)
+        console.print()
+
+        # Vibe Coding hint - clean formatting with proper spacing
+        console.print("[bold yellow]💡 Vibe Coding:[/bold yellow] Use Claude/Cursor/Codex with")
+        console.print(f"   [cyan]co-vibecoding-principles-docs-contexts-all-in-one.md[/cyan]")
     else:
-        console.print(f"📦 Template: {Colors.BOLD}{template.title()}{Colors.END}")
-
-    if custom_code and description:
-        console.print(f"\n✨ {Colors.CYAN}Custom agent generated from:{Colors.END}")
-        console.print(f"   {description[:60]}...")
-
-    # Show agent address and email (using global)
-    if 'addr_data' in locals() and addr_data.get('address'):
-        console.print(f"\n🔑 Agent address: {Colors.CYAN}{addr_data['address']}{Colors.END} (global)")
-        if addr_data.get('email'):
-            console.print(f"📧 Agent email: {Colors.CYAN}{addr_data['email']}{Colors.END} (global)")
-
-        console.print(f"\n💡 {Colors.CYAN}Using global identity. Run 'co address' to create project-specific identity.{Colors.END}")
-
-    if files_created:
-        console.print(f"\n{Colors.CYAN}📂 Files created:{Colors.END}")
-        for file in files_created:
-            if file == "agent.py":
-                console.print(f"  • {Colors.GREEN}{file}{Colors.END} - Main agent implementation")
-            elif file == "prompts/":
-                console.print(f"  • {Colors.GREEN}{file}{Colors.END} - System prompts directory")
-            elif file == ".env":
-                console.print(f"  • {Colors.GREEN}{file}{Colors.END} - Environment configuration (add your API key)")
-            elif file == "README.md":
-                console.print(f"  • {Colors.GREEN}{file}{Colors.END} - Project documentation")
-            elif file == ".co/":
-                console.print(f"  • {Colors.GREEN}{file}{Colors.END} - ConnectOnion metadata")
-            elif file == ".co/keys/":
-                console.print(f"  • {Colors.GREEN}{file}{Colors.END} - Agent cryptographic keys")
-            else:
-                console.print(f"  • {Colors.GREEN}{file}{Colors.END}")
-
-    if files_skipped:
-        console.print(f"\n{Colors.YELLOW}⚠️  Skipped (already exist):{Colors.END}")
-        for file in files_skipped:
-            console.print(f"  • {file}")
-
-    # Automatically authenticate with OpenOnion to get JWT token for co/ models
-    # Use the GLOBAL ~/.co directory for authentication, not the project directory
-    global_co_dir = Path.home() / ".co"
-
-    # If global folder doesn't exist, create it and set up keys
-    if not global_co_dir.exists():
-        console.print(f"\n{Colors.CYAN}🔧 Setting up global ConnectOnion configuration...{Colors.END}")
-        ensure_global_config()
-
-    # Now authenticate with the global directory
-    console.print(f"\n{Colors.CYAN}🔐 Authenticating with OpenOnion for managed models...{Colors.END}")
-    auth_success = authenticate(global_co_dir)  # Pass the global dir where keys are
-
-    if auth_success:
-        console.print(f"{Colors.GREEN}✅ Authentication successful! You can now use co/ models.{Colors.END}")
-    else:
-        console.print(f"{Colors.YELLOW}⚠️  Authentication skipped. Run 'co auth' later to use co/ models.{Colors.END}")
-
-    # Show .env reminder based on API key setup
-    console.print("")
-    if api_key and provider:
-        if provider == "connectonion":
-            console.print(f"💡 {Colors.CYAN}Using ConnectOnion credits - add your own key to .env if needed{Colors.END}")
-        else:
-            console.print(f"💡 {Colors.CYAN}API key saved to .env - edit anytime to change providers{Colors.END}")
-    else:
-        console.print(f"💡 {Colors.YELLOW}Add your API key to .env file to enable AI features{Colors.END}")
-
-    # Next steps with color coding
-    console.print(f"\n{Colors.CYAN}🚀 Next steps:{Colors.END}")
-    console.print(f"{Colors.CYAN}{'─' * 40}{Colors.END}")
-
-    step = 1
-    if not api_key:
-        console.print(f"\n{step}️⃣  Add your API key to .env:")
-        console.print(f"    Open {Colors.BOLD}.env{Colors.END} and replace 'sk-your-api-key-here'")
-        step += 1
-
-    console.print(f"\n{step}️⃣  Install dependencies:")
-    console.print(f"    {Colors.BOLD}pip install python-dotenv{Colors.END}")
-    step += 1
-
-    if template == "playwright":
-        console.print(f"    {Colors.BOLD}pip install playwright{Colors.END}")
-        console.print(f"    {Colors.BOLD}playwright install{Colors.END}")
-        step += 1
-
-    console.print(f"\n{step}️⃣  Run your agent:")
-    console.print(f"    {Colors.BOLD}python agent.py{Colors.END}")
-
-    console.print(f"\n{Colors.CYAN}📚 Resources:{Colors.END}")
-    console.print(f"   Documentation: {Colors.UNDERLINE}https://docs.connectonion.com{Colors.END}")
-    console.print(f"   Discord: {Colors.UNDERLINE}https://discord.gg/4xfD9k8AUF{Colors.END}")
-
-    # GitHub star request
-    console.print(f"\n{Colors.CYAN}⭐ Support ConnectOnion:{Colors.END}")
-    console.print(f"   Get 100K free tokens by starring our GitHub repo!")
-
-    # Check if gh CLI is installed and star the repo
-    try:
-        # Check if gh is installed
-        gh_check = subprocess.run(["which", "gh"], capture_output=True, text=True)
-        if gh_check.returncode == 0:
-            # Check if already starred
-            star_check = subprocess.run(
-                ["gh", "api", "user/starred/wu-changxing/connectonion"],
-                capture_output=True,
-                text=True
-            )
-
-            if star_check.returncode != 0:
-                # Not starred yet, star it
-                console.print(f"   {Colors.YELLOW}Starring the ConnectOnion repo...{Colors.END}")
-                star_result = subprocess.run(
-                    ["gh", "api", "--method", "PUT", "user/starred/wu-changxing/connectonion"],
-                    capture_output=True,
-                    text=True
-                )
-                if star_result.returncode == 0:
-                    console.print(f"   {Colors.GREEN}✅ Thank you for starring ConnectOnion!{Colors.END}")
-                    console.print(f"   {Colors.GREEN}🎁 Your 100K tokens will be credited shortly.{Colors.END}")
-                else:
-                    console.print(f"   {Colors.YELLOW}⚠️  Couldn't star automatically. Please star manually:{Colors.END}")
-                    console.print(f"   {Colors.UNDERLINE}https://github.com/wu-changxing/connectonion{Colors.END}")
-            else:
-                console.print(f"   {Colors.GREEN}✅ You've already starred ConnectOnion. Thank you!{Colors.END}")
-        else:
-            # gh CLI not installed
-            console.print(f"   {Colors.YELLOW}Star us on GitHub:{Colors.END} {Colors.UNDERLINE}https://github.com/wu-changxing/connectonion{Colors.END}")
-    except Exception:
-        # Fallback if any error occurs
-        console.print(f"   {Colors.YELLOW}Star us on GitHub:{Colors.END} {Colors.UNDERLINE}https://github.com/wu-changxing/connectonion{Colors.END}")
+        # Vibe Coding hint for building from scratch
+        console.print("[bold yellow]💡 Vibe Coding:[/bold yellow] Use Claude/Cursor/Codex with")
+        console.print(f"   [cyan]co-vibecoding-principles-docs-contexts-all-in-one.md[/cyan]")
+        console.print("   to build your agent")
 
+    # Resources - clean format with arrows for better alignment
+    console.print()
+    console.print("[bold cyan]📚 Resources:[/bold cyan]")
+    console.print(f"   Docs    [dim]→[/dim] [link=https://docs.connectonion.com][blue]https://docs.connectonion.com[/blue][/link]")
+    console.print(f"   Discord [dim]→[/dim] [link=https://discord.gg/4xfD9k8AUF][blue]https://discord.gg/4xfD9k8AUF[/blue][/link]")
+    console.print(f"   GitHub  [dim]→[/dim] [link=https://github.com/openonion/connectonion][blue]https://github.com/openonion/connectonion[/blue][/link] [dim](⭐ star us!)[/dim]")
     console.print()
 
     # Clean up temporary project directory if created for authentication
